@@ -361,7 +361,7 @@ int Treebytes;
 
 TREE *Solver::pack_position(void)
 {
-	int j, k, w;
+	int j, w;
 	quint8 *p;
 	TREE *node;
 
@@ -384,7 +384,6 @@ TREE *Solver::pack_position(void)
 		    p         p         p
 	*/
 
-	k = 0;
         quint16 *p2 = ( quint16* ) p;
 	for (w = 0; w < m_number_piles; ++w) {
 		j = Wpilenum[w];
@@ -418,7 +417,7 @@ array following the POSITION struct. */
 
 void Solver::unpack_position(POSITION *pos)
 {
-	int i, k, w;
+	int i, w;
 	quint8 c;
 	BUCKETLIST *l;
 
@@ -432,7 +431,7 @@ void Solver::unpack_position(POSITION *pos)
 		       j             j
 	*/
 
-	k = w = i = c = 0;
+	w = i = c = 0;
 	quint16 *p2 = ( quint16* )( (quint8 *)(pos->node) + sizeof(TREE) );
 	while (w < m_number_piles) {
                 i = *p2++;
@@ -1012,9 +1011,6 @@ int Solver::translate_pile(const KCardPile *pile, card_t *w, int size)
     Q_UNUSED( size );
         Q_ASSERT( pile->count() <= size );
 
-        card_t rank, suit;
-
-	rank = suit = NONE;
         for ( int i = 0; i < pile->count(); ++i )
         {
             KCard *c = pile->at( i );
